@@ -15,19 +15,18 @@
 import json
 from typing import Dict
 
-from robotlibcore import keyword  # type: ignore
-
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import keyword, logger
 
 
 class Devices(LibraryComponent):
-    @keyword(tags=["Getter", "BrowserControl"])
+    @keyword(tags=("Getter", "BrowserControl"))
     def get_devices(self) -> Dict:
         """Returns a dict of all playwright device descriptors.
 
-        See Playwright's [https://github.com/Microsoft/playwright/blob/master/src/deviceDescriptors.ts | deviceDescriptors.ts]
+        See Playwright's
+        [https://github.com/microsoft/playwright/blob/master/src/server/deviceDescriptorsSource.json|deviceDescriptorsSource.json]
         for a formatted list.
         """
         with self.playwright.grpc_channel() as stub:
@@ -35,13 +34,13 @@ class Devices(LibraryComponent):
             logger.debug(response.log)
             return json.loads(response.json)
 
-    @keyword(tags=["Getter", "BrowserControl"])
+    @keyword(tags=("Getter", "BrowserControl"))
     def get_device(self, name: str) -> Dict:
-        """Get a single device decriptor with name exactly matching name.
+        """Get a single device descriptor with name exactly matching name.
 
-        ``name`` <str> Given name of the requested device. See Playwright's
-        [https://github.com/Microsoft/playwright/blob/master/src/deviceDescriptors.ts | deviceDescriptors.ts]
-        for a formatted list. **Required**
+        ``name`` Given name of the requested device. See Playwright's
+        [https://github.com/Microsoft/playwright/blob/master/src/server/deviceDescriptors.ts | deviceDescriptors.ts]
+        for a formatted list.
 
         Allows a concise syntax to set website testing values to exact matches of specific
         mobile devices.
