@@ -35,7 +35,10 @@ class Promises(LibraryComponent):
     def promise_to(self, kw: str, *args) -> Future:
         """
         Wrap a Browser library keyword and make it a promise.
-        Returns that promise and executes the keyword on background.
+        Promised keyword is executed and started on background.
+        Test execution continues without waiting for ``kw`` to finish.
+
+        Returns reference to the promised keyword.
 
         ``kw`` Keyword that will work async on background.
 
@@ -79,7 +82,7 @@ class Promises(LibraryComponent):
         Example usage:
         | New Context          acceptDownloads=True
         | New Page             ${LOGIN_URL}
-        | ${dl_promise}        Promise To Wait For Download    /path/to/download/folder
+        | ${dl_promise}        Promise To Wait For Download    /path/to/download/file.name
         | Click                \\#file_download
         | ${file_obj}=         Wait For  ${dl_promise}
         | File Should Exist    ${file_obj}[saveAs]
@@ -89,11 +92,6 @@ class Promises(LibraryComponent):
         self.unresolved_promises.add(promise)
         return promise
 
-    @keyword(tags=("Wait", "BrowserControl"))
-    def wait_for_download(self, saveAs: str = "") -> DownloadedFile:
-        """*DEPRECATED!!* Use keyword `Promise To Wait For Download` instead."""
-        return self._wait_for_download(saveAs)
-
     def _wait_for_download(self, saveAs: str = "") -> DownloadedFile:
         with self.playwright.grpc_channel() as stub:
             if not saveAs:
@@ -116,6 +114,10 @@ class Promises(LibraryComponent):
         Returns one result if one promise waited. Otherwise returns an array of results.
         If one fails, then this keyword will fail.
 
+        See `Promise To` for more information about promises.
+
+        For general waiting of elements please see `Implicit waiting`.
+
         ``promises`` *Work in progress*
 
         Example:
@@ -157,21 +159,6 @@ class Promises(LibraryComponent):
         self.unresolved_promises.add(promise)
         return promise
 
-    @keyword(tags=("Setter", "PageContent"))
-    def upload_file(self, path: PathLike):
-        """*DEPRECATED!!* Use keyword `Promise To Upload File` instead.
-        Upload file from ``path`` into next file chooser dialog on page.
-
-        ``path`` Path to file to be uploaded.
-
-        Example use:
-
-        | Upload File    ${CURDIR}/test_upload_file
-        | Click          \\#file_chooser
-
-        """
-        return self._upload_file(path)
-
     def _upload_file(self, path: PathLike):
         p = Path(path)
         p.resolve(strict=True)
